@@ -4,6 +4,7 @@
 import argparse
 import os
 
+from .. import __version__
 from ..base import skedding, consoling
 
 def parseArgs():
@@ -12,6 +13,10 @@ def parseArgs():
     d = "Runs ioflo. "
     d += "Example: ioflo -f filename -p period -v level -r -h -b 'mybehaviors.py'\n"
     p = argparse.ArgumentParser(description = d)
+    p.add_argument('-V','--version',
+            action='version',
+            version=__version__,
+            help="Prints out version of ioflo.")
     p.add_argument('-v','--verbose',
             action='store',
             default='concise',
@@ -26,18 +31,13 @@ def parseArgs():
             const=True,
             default=False,
             help="Run skedder at realtime.")
-    p.add_argument('-V','--version',
-            action='store_const',
-            const=True,
-            default=False,
-            help="Prints out version of ioflo.")
     p.add_argument('-n','--name',
             action='store',
             default='skedder',
             help="Skedder name.")
     p.add_argument('-f','--filename',
             action='store',
-            default='',
+            required=True,
             help="File path to FloScript file.")
     p.add_argument('-b','--behaviors',
             action='store',
@@ -139,55 +139,3 @@ def run(    name="skedder",
 
 Run = run # alias for backwards compat
 start = run # alias for backwards compat
-
-#def start(
-            #name="skedder",
-            #period=0.1,
-            #stamp=0.0,
-            #real=False,
-            #filepath="",
-            #behaviors=None,
-            #username="",
-            #password="",
-            #mode=None,
-            #houses=None,
-            #metas=None,
-            #preloads=None,
-            #verbose=0,
-        #):
-    #""" Start Skedder, build and run """
-    #console = consoling.getConsole(verbosity=consoling.Console.Wordage[verbose])
-    #console.terse( "\n----------------------\n")
-    #console.terse( "Building Skedder '{0}' ...\n".format(name))
-
-    #if not filepath:
-        #console.terse( "\n\n**********************************\n")
-        #console.terse("Empty filepath. Aborting!!!")
-        #return
-
-    #skedder = skedding.Skedder(name=name,
-                               #period=period,
-                               #stamp=stamp,
-                               #real=real,
-                               #filepath=filepath,
-                               #behaviors=behaviors,
-                               #username=username,
-                               #password=password,
-                               #mode=mode,
-                               #houses=houses,
-                               #metas=metas,
-                               #preloads=preloads, )
-    #if skedder.build():
-        #console.terse( "\n----------------------\n")
-        #console.terse( "\n\nStarting mission plan '{0}' ... from file {1}\n".format(
-                #skedder.plan, skedder.filepath))
-        #skedder.run()
-    #else:
-        #console.terse( "\n\n**********************************\n")
-        #console.terse( "Failure building mission from file:\n{0}\n".format(
-                 #skedder.filepath))
-        #console.terse( "************************************\n\n")
-
-    #console.terse( "\n----------------------\n")
-    #return skedder
-
